@@ -1,5 +1,5 @@
 from matrixcalc import matrixcalc
-version = "v0.1.5"
+version = "v0.1.6"
 
 def template(m, n):
     position = 11
@@ -26,7 +26,7 @@ def construct_matrix(letter, rows):
 class Interface(object):
 
     def menu(self):
-        print("Welcome to MatrixCalc %s" % version)
+        print("Welcome to MatrixCalculator %s" % version)
         print("""
         1. Add matrices
         2. Subtract matrices
@@ -34,7 +34,8 @@ class Interface(object):
         4. Scalar multiply matrices
         5. Transpose a matrix
         6. Find determinant of a matrix
-        7. Exit
+        7. Find inverse of a matrix
+        8. Exit
         """)
 
         selection = input("Please input the number of your selection: ")
@@ -53,6 +54,8 @@ class Interface(object):
             elif selection == "6":
                 return Interface().det()
             elif selection == "7":
+                return Interface().inverse()
+            elif selection == "8":
                 exit()
 
             selection = input("Input not recognized. Please re-enter your selection: ")
@@ -77,15 +80,15 @@ class Interface(object):
         print("\nAnswer:")
         matrixcalc.print_matrix(ab)
 
-        input("\nPress ENTER to return to the menu")
+        input("\nPress ENTER to return to the menu\n")
         Interface().menu()
 
     def mul(self):
-        row1 = int(input("\nHow many rows are in your Matrix A? "))
-        col1 = int(input("How many columns are in your Matrix A? "))
+        row1 = int(input("\nHow many rows are in Matrix A? "))
+        col1 = int(input("How many columns are in Matrix A? "))
 
-        row2 = int(input("\nHow many rows are in your Matrix B? "))
-        col2 = int(input("How many columns are in your Matrix B? "))
+        row2 = int(input("\nHow many rows are in Matrix B? "))
+        col2 = int(input("How many columns are in Matrix B? "))
 
         print()
         template(row1, col1)
@@ -103,7 +106,7 @@ class Interface(object):
         print("\nThe product of Matrix A and Matrix B is:")
         matrixcalc.print_matrix(ab)
 
-        input("\nPress ENTER to return to the menu")
+        input("\nPress ENTER to return to the menu\n")
         Interface().menu()
 
     def scalar_mul(self):
@@ -121,7 +124,7 @@ class Interface(object):
         print("\nThe scalar product of Matrix A is:")
         matrixcalc.print_matrix(scalar_a)
 
-        input("\nPress ENTER to return to the menu")
+        input("\nPress ENTER to return to the menu\n")
         Interface().menu()
 
     def transpose(self):
@@ -138,7 +141,7 @@ class Interface(object):
         print("\nThe tranposed matrix of Matrix A is:")
         matrixcalc.print_matrix(transpose_a)
 
-        input("\nPress ENTER to return to the menu")
+        input("\nPress ENTER to return to the menu\n")
         Interface().menu()
 
     def det(self):
@@ -153,5 +156,21 @@ class Interface(object):
 
         print("\nThe determinant of Matrix A is: %s" % det_a)
 
-        input("\nPress ENTER to return to the menu")
+        input("\nPress ENTER to return to the menu\n")
+        Interface().menu()
+
+    def inverse(self):
+        rows = int(input("\nHow many rows and columns are in your matrix? "))
+
+        print()
+        template(rows, rows)
+        print()
+
+        a = construct_matrix("A", rows)
+        inverse_a = matrixcalc.inverse(a)
+
+        print("\nThe inverse of Matrix A is:")
+        matrixcalc.print_matrix(inverse_a)
+
+        input("\nPress ENTER to return to the menu\n")
         Interface().menu()
